@@ -128,6 +128,11 @@ class Axis(object):
         self.y = xyz[0][1]
         self.z = xyz[0][2]
 
+    def transformed(self, transformation):
+        xyz = transform_vectors(
+            [[self.x, self.y, self.z]], transformation.matrix)
+        return Vector(xyz[0][0], xyz[0][1], xyz[0][2])
+
     @property
     def vector(self):
         return Vector(self.x, self.y, self.z)
@@ -184,8 +189,8 @@ class Joint(object):
         self.type = Joint.SUPPORTED_TYPES.index(type)
         self.parent = parent if isinstance(parent, ParentLink) else ParentLink(parent)
         self.child = child if isinstance(child, ChildLink) else ChildLink(child)
-        self.origin = origin
-        self.axis = axis
+        self.origin = origin or Origin.from_euler_angles([0., 0., 0.])
+        self.axis = axis or Axis()
         self.calibration = calibration
         self.dynamics = dynamics
         self.limit = limit
@@ -194,8 +199,6 @@ class Joint(object):
         self.attr = kwargs
         self.child_link = None
         self.position = 0
-        self.init_origin = origin.copy() if origin else None
-        self.init_axis = axis.copy() if axis else None
 
         switcher = {
             Joint.REVOLUTE: self.calculate_revolute_transformation,
@@ -215,23 +218,6 @@ class Joint(object):
         else:
             return Transformation()
 
-    @property
-    def init_transformation(self):
-        if self.init_origin:
-            return Transformation.from_frame(self.init_origin)
-        else:
-            return Transformation()
-
-    @property
-    def reset_transformation(self):
-        return self.init_transformation * self.current_transformation.inverse()
-
-    def reset_transform(self):
-        if self.init_origin:
-            self.origin = self.init_origin.copy()
-        if self.init_axis:
-            self.axis = self.init_axis.copy()
-
     def transform(self, transformation):
         if self.origin:
             self.origin.transform(transformation)
@@ -241,10 +227,8 @@ class Joint(object):
     def create(self, transformation):
         if self.origin:
             self.origin.transform(transformation)
-            self.init_origin = self.origin.copy()
         if self.axis:
             self.axis.transform(self.current_transformation)
-            self.init_axis = self.axis.copy()
 
     def calculate_revolute_transformation(self, position):
         """Returns a transformation of a revolute joint.
@@ -255,6 +239,9 @@ class Joint(object):
         Args:
             position (float): the angle in radians
         """
+        if not self.limit:
+            raise ValueError('Revolute joints are required to define a limit')
+
         position = max(min(position, self.limit.upper), self.limit.lower)
         return self.calculate_continous_transformation(position)
 
@@ -278,6 +265,9 @@ class Joint(object):
         Args:
             position (float): the movement in meters.
         """
+        if not self.limit:
+            raise ValueError('Prismatic joints are required to define a limit')
+
         position = max(min(position, self.limit.upper), self.limit.lower)
         return Translation(self.axis.vector * position)
 
@@ -317,19 +307,17 @@ class Joint(object):
     def is_configurable(self):
         """Returns ``True`` if the joint can be configured, otherwise ``False``."""
         return self.type != Joint.FIXED
-    
+
     def is_scalable(self):
         """Returns ``True`` if the joint can be scaled, otherwise ``False``."""
         return self.type in [Joint.PLANAR, Joint.PRISMATIC]
 
     def scale(self, factor):
         self.origin.scale(factor)
-        self.init_origin.point *= factor
         if self.is_scalable():
             self.limit.scale(factor)
 
 
-
 URDFParser.install_parser(Joint, 'robot/joint')
 URDFParser.install_parser(ParentLink, 'robot/joint/parent')
 URDFParser.install_parser(ChildLink, 'robot/joint/child')
