@@ -4,7 +4,7 @@ from __future__ import print_function
 
 from compas.files import URDF
 from compas.files import URDFParser
-from compas.geometry.xforms import Transformation
+from compas.geometry import Transformation
 
 from compas.robots.model.geometry import Box
 from compas.robots.model.geometry import Capsule
@@ -82,8 +82,9 @@ class Visual(object):
         self.material = material
         self.attr = kwargs
 
-    def draw(self):
-        return self.geometry.draw()
+        self.init_transformation = None  # to store the init transformation
+        self.current_transformation = None  # to store the current transformation
+        self.native_geometry = None  # to store the link's CAD native geometry
 
     def get_color(self):
         if self.material:
@@ -109,8 +110,9 @@ class Collision(object):
         self.name = name
         self.attr = kwargs
 
-    def draw(self):
-        return self.geometry.draw()
+        self.init_transformation = None  # to store the init transformation
+        self.current_transformation = None  # to store the current transformation
+        self.native_geometry = None  # to store the link's CAD native geometry
 
 
 class Link(object):
@@ -139,8 +141,6 @@ class Link(object):
         self.parent_joint = None
 
 
-
-
 URDFParser.install_parser(Link, 'robot/link')
 URDFParser.install_parser(Inertial, 'robot/link/inertial')
 URDFParser.install_parser(Mass, 'robot/link/inertial/mass')
